@@ -24,6 +24,7 @@ from mypy_boto3_codeguru_reviewer.type_defs import (
     DescribeRecommendationFeedbackResponseTypeDef,
     DescribeRepositoryAssociationResponseTypeDef,
     DisassociateRepositoryResponseTypeDef,
+    KMSKeyDetailsTypeDef,
     ListCodeReviewsResponseTypeDef,
     ListRecommendationFeedbackResponseTypeDef,
     ListRecommendationsResponseTypeDef,
@@ -62,7 +63,7 @@ class Exceptions:
 
 class CodeGuruReviewerClient:
     """
-    [CodeGuruReviewer.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.57/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client)
+    [CodeGuruReviewer.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.58/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client)
     """
 
     meta: ClientMeta
@@ -73,14 +74,15 @@ class CodeGuruReviewerClient:
         Repository: RepositoryTypeDef,
         ClientRequestToken: str = None,
         Tags: Dict[str, str] = None,
+        KMSKeyDetails: "KMSKeyDetailsTypeDef" = None,
     ) -> AssociateRepositoryResponseTypeDef:
         """
-        [Client.associate_repository documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.57/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.associate_repository)
+        [Client.associate_repository documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.58/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.associate_repository)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.57/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.58/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.can_paginate)
         """
 
     def create_code_review(
@@ -91,31 +93,31 @@ class CodeGuruReviewerClient:
         ClientRequestToken: str = None,
     ) -> CreateCodeReviewResponseTypeDef:
         """
-        [Client.create_code_review documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.57/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.create_code_review)
+        [Client.create_code_review documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.58/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.create_code_review)
         """
 
     def describe_code_review(self, CodeReviewArn: str) -> DescribeCodeReviewResponseTypeDef:
         """
-        [Client.describe_code_review documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.57/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.describe_code_review)
+        [Client.describe_code_review documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.58/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.describe_code_review)
         """
 
     def describe_recommendation_feedback(
         self, CodeReviewArn: str, RecommendationId: str, UserId: str = None
     ) -> DescribeRecommendationFeedbackResponseTypeDef:
         """
-        [Client.describe_recommendation_feedback documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.57/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.describe_recommendation_feedback)
+        [Client.describe_recommendation_feedback documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.58/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.describe_recommendation_feedback)
         """
 
     def describe_repository_association(
         self, AssociationArn: str
     ) -> DescribeRepositoryAssociationResponseTypeDef:
         """
-        [Client.describe_repository_association documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.57/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.describe_repository_association)
+        [Client.describe_repository_association documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.58/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.describe_repository_association)
         """
 
     def disassociate_repository(self, AssociationArn: str) -> DisassociateRepositoryResponseTypeDef:
         """
-        [Client.disassociate_repository documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.57/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.disassociate_repository)
+        [Client.disassociate_repository documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.58/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.disassociate_repository)
         """
 
     def generate_presigned_url(
@@ -126,7 +128,7 @@ class CodeGuruReviewerClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.57/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.58/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.generate_presigned_url)
         """
 
     def list_code_reviews(
@@ -141,7 +143,7 @@ class CodeGuruReviewerClient:
         NextToken: str = None,
     ) -> ListCodeReviewsResponseTypeDef:
         """
-        [Client.list_code_reviews documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.57/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_code_reviews)
+        [Client.list_code_reviews documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.58/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_code_reviews)
         """
 
     def list_recommendation_feedback(
@@ -153,14 +155,14 @@ class CodeGuruReviewerClient:
         RecommendationIds: List[str] = None,
     ) -> ListRecommendationFeedbackResponseTypeDef:
         """
-        [Client.list_recommendation_feedback documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.57/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_recommendation_feedback)
+        [Client.list_recommendation_feedback documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.58/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_recommendation_feedback)
         """
 
     def list_recommendations(
         self, CodeReviewArn: str, NextToken: str = None, MaxResults: int = None
     ) -> ListRecommendationsResponseTypeDef:
         """
-        [Client.list_recommendations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.57/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_recommendations)
+        [Client.list_recommendations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.58/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_recommendations)
         """
 
     def list_repository_associations(
@@ -177,12 +179,12 @@ class CodeGuruReviewerClient:
         NextToken: str = None,
     ) -> ListRepositoryAssociationsResponseTypeDef:
         """
-        [Client.list_repository_associations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.57/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_repository_associations)
+        [Client.list_repository_associations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.58/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_repository_associations)
         """
 
     def list_tags_for_resource(self, resourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
-        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.57/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_tags_for_resource)
+        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.58/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_tags_for_resource)
         """
 
     def put_recommendation_feedback(
@@ -192,22 +194,22 @@ class CodeGuruReviewerClient:
         Reactions: List[Literal["ThumbsUp", "ThumbsDown"]],
     ) -> Dict[str, Any]:
         """
-        [Client.put_recommendation_feedback documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.57/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.put_recommendation_feedback)
+        [Client.put_recommendation_feedback documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.58/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.put_recommendation_feedback)
         """
 
     def tag_resource(self, resourceArn: str, Tags: Dict[str, str]) -> Dict[str, Any]:
         """
-        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.57/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.tag_resource)
+        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.58/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.tag_resource)
         """
 
     def untag_resource(self, resourceArn: str, TagKeys: List[str]) -> Dict[str, Any]:
         """
-        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.57/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.untag_resource)
+        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.58/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.untag_resource)
         """
 
     def get_paginator(
         self, operation_name: Literal["list_repository_associations"]
     ) -> ListRepositoryAssociationsPaginator:
         """
-        [Paginator.ListRepositoryAssociations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.57/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Paginator.ListRepositoryAssociations)
+        [Paginator.ListRepositoryAssociations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.58/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Paginator.ListRepositoryAssociations)
         """
